import {Component, h} from 'preact';
import {PopoverMenu} from '../popover-menu';
import {PopoverMenuItemData} from '../popover-menu';

import {Button, ButtonType} from '@playkit-js/common/dist/components/button';
const {withText, Text} = KalturaPlayer.ui.preacti18n;

interface TranscriptMenuProps {
  printTranscript?: string;
  downloadTranscript?: string;
  onDownload: () => void;
  onPrint: () => void;
  downloadDisabled?: boolean;
  printDisabled?: boolean;
  isLoading?: boolean;
}

interface TranscriptMenuState {
  items: Array<PopoverMenuItemData>;
}

const translates = {
  printTranscript: <Text id="transcript.print_transcript">Print current transcript</Text>,
  downloadTranscript: <Text id="transcript.download_transcript">Download current transcript</Text>
};

@withText(translates)
class LiveTranscriptMenu extends Component<TranscriptMenuProps, TranscriptMenuState> {
  constructor(props: TranscriptMenuProps) {
    super();

    const {downloadDisabled, onDownload, printDisabled, onPrint, printTranscript, downloadTranscript, isLoading} = props;
    const items = [];
    items.push({
      testId: 'download-menu-item',
      label: downloadTranscript!,
      onClick: onDownload,
      isDisabled: downloadDisabled && !isLoading,
      tooltip: 'Not available while LIVE',
    });

    items.push({
      testId: 'print-menu-item',
      label: printTranscript!,
      onClick: onPrint,
      isDisabled: printDisabled && !isLoading,
      tooltip: 'Not available while LIVE',
    });

    this.state = {items};
  }

  render() {
    return this.state.items.length ? (
      <PopoverMenu items={this.state.items}>
        <Button type={ButtonType.borderless} icon={'more'} tabIndex={-1} />
      </PopoverMenu>
    ) : null;
  }
}

export {LiveTranscriptMenu};
